@@ -2,14 +2,19 @@ from .manage_yaml import Yaml
 from .manage_time import Montre
 from .manage_file import create_all_parents, searching_all_files, unzip, pbar
 from . import load_google_drive
-from .pickle_wrapper import load_pickle, dump_pickle
+from . import google
 from . import stutils
+from . import meteo
+from . import easy_import
+from .pickle_wrapper import load_pickle, dump_pickle
+from .regress2 import regress2
 
 __all__ = [
     "Yaml", 
     "Montre", 
     "create_all_parents", "searching_all_files", "unzip", "pbar",
-    "load_google_drive",
+    "load_google_drive", "google",
     "load_pickle", "dump_pickle",
-    "stutils"
+    "stutils", "regress2",
+    "easy_import"
     ]
\ No newline at end of file
